'use client'
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import { useTranslation } from "@/src/hooks/useTranslation";
import { Tooltip } from "@nextui-org/react";
import { useState } from "react";
import { Search, X } from "react-feather";

export default function SearchConversations() {

  const { trans } = useTranslation();
  const [search, setSearch] = useState("");
  const [closeSearch, setCloseSearch] = useState(false);
  const setFilter = useConversationsStore(state => state.actions.setFilter);

  const handlerSeacrhConversation = (event: any) => {
    event.preventDefault();
    const searchValue = event.target.value;
    setSearch(searchValue);
    setFilter({ type: 'search', value: searchValue , tags:[]});
    if (searchValue === "") {
      setCloseSearch(false);
    } else {
      setCloseSearch(true);
    }
  }

  const handlerCloseSearch = () => {
    setSearch("");
    setFilter({ type: 'search', value: '', tags:[]});
    setCloseSearch(false);
  }

  return (
    <div className={`py-2 sm:py-2 flex flex-row items-center w-full transition ease-in-out delay-150 duration-300 dark:bg-gray-700 bg-indigo-500 md:bg-white text-white md:text-black`}>
      <div className="w-full flex flex-row justify-center items-center px-5">
        <label htmlFor="simple-search" className="sr-only">Search</label>
        <div className="relative w-full">
          <div className="absolute inset-y-0 start-0 flex items-center ps-3 pointer-events-none">
            <Search className="text-white md:text-gray-500" size={20} />
          </div>
          <input type="text" value={search} onChange={handlerSeacrhConversation} onKeyDown={(e) => { e.key === 'Enter' && e.preventDefault(); }} className="focus:outline-none focus:ring-0 focus:border-transparent bg-indigo-400 md:bg-gray-50 border border-indigo-400 md:border-gray-100 text-white md:text-gray-900 text-sm rounded-lg block w-full ps-10 p-2.5  dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white placeholder-white md:placeholder-gray-400" placeholder={trans("search_placeholder_conversations")} />
          <button onClick={() => handlerCloseSearch()} type="button" className={`${closeSearch ? 'block' : 'hidden'} absolute top-0 end-0 p-2.5 h-full text-sm font-medium text-white bg-indigo-400 md:bg-gray-50 focus:outline-none focus:ring-blue-300`} >
            <Tooltip
              placement="right"
              content={trans('search_close_text')}
              color="default"
            >
              <X className="text-white md:text-gray-500 cursor-pointer hover:text-gray-950" size={20} />
            </Tooltip>
          </button>
        </div>
      </div>
    </div>
  )
}
